@@ -95,7 +95,6 @@ __other_words = {
         "krumiro",
         "pezzi",
         "spremere",
-        "succo",
         "romano",
         "datterini",
         "sungold",
@@ -287,7 +286,6 @@ __other_words = {
         "nordico",
         "mezze",
         "estivo",
-        "lievito",
         "base",
         "cremor",
         "tartaro",
@@ -537,7 +535,6 @@ __other_words = {
         "all",
         "purpose",
         "crushed",
-        "juice",
         "more",
         "bell",
         "needed",
@@ -756,7 +753,6 @@ __other_words = {
         "Nordic",
         "mezze",
         "summer",
-        "yeast",
         "base",
         "cremor",
         "tartar",
@@ -854,6 +850,7 @@ __categories = {
         "cioccolato",
         "funghi",
         "fungo",
+        "tonnato",
     ],
     "en": [
         "ice cream",
@@ -879,6 +876,7 @@ __categories = {
         "vegetable",
         "chocolate",
         "mushroom",
+        "veal",
     ],
 }
 
